@@ -7,7 +7,7 @@ RDF::Trine::Serializer::NTriples - NTriples Serializer.
 
 =head1 VERSION
 
-This document describes RDF::Trine::Serializer::NTriples version 0.112_01
+This document describes RDF::Trine::Serializer::NTriples version 0.112_02
 
 =head1 SYNOPSIS
 
@@ -43,7 +43,7 @@ use RDF::Trine::Error qw(:try);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.112_01';
+	$VERSION	= '0.112_02';
 }
 
 ######################################################################
@@ -62,10 +62,10 @@ sub new {
 	return $self;
 }
 
-=item C<< serialize_model_to_file ( $file, $model ) >>
+=item C<< serialize_model_to_file ( $fh, $model ) >>
 
 Serializes the C<$model> to NTriples, printing the results to the supplied
-C<$file> handle.
+filehandle C<<$fh>>.
 
 =cut
 
@@ -75,7 +75,7 @@ sub serialize_model_to_file {
 	my $model	= shift;
 	my $iter	= $model->as_stream;
 	while (my $st = $iter->next) {
-		print {$file} join(' ', map { $_->as_ntriples } $st->nodes) . " .\n";
+		print {$file} $self->_statement_as_string( $st );
 	}
 }
 
@@ -92,7 +92,64 @@ sub serialize_model_to_string {
 	my $string	= '';
 	while (my $st = $iter->next) {
 		my @nodes	= $st->nodes;
-		$string		.= join(' ', map { $_->sse } @nodes) . " .\n";
+		$string		.= $self->_statement_as_string( $st );
+	}
+	return $string;
+}
+
+=item C<< serialize_iterator_to_file ( $file, $iter ) >>
+
+Serializes the iterator to NTriples, printing the results to the supplied
+filehandle C<<$fh>>.
+
+=cut
+
+sub serialize_iterator_to_file {
+	my $self	= shift;
+	my $file	= shift;
+	my $iter	= shift;
+	while (my $st = $iter->next) {
+		print {$file} $self->_statement_as_string( $st );
+	}
+}
+
+sub _statement_as_string {
+	my $self	= shift;
+	my $st		= shift;
+	return join(' ', map { $_->as_ntriples } $st->nodes) . " .\n";
+}
+
+=item C<< serialize_iterator_to_string ( $iter ) >>
+
+Serializes the iterator to NTriples, returning the result as a string.
+
+=cut
+
+sub serialize_iterator_to_string {
+	my $self	= shift;
+	my $iter	= shift;
+	my $string	= '';
+	while (my $st = $iter->next) {
+		my @nodes	= $st->nodes;
+		$string		.= $self->_statement_as_string( $st );
+	}
+	return $string;
+}
+
+sub _serialize_bounded_description {
+	my $self	= shift;
+	my $model	= shift;
+	my $node	= shift;
+	my $seen	= shift || {};
+	return '' if ($seen->{ $node->sse }++);
+	my $iter	= $model->get_statements( $node, undef, undef );
+	my $string	= '';
+	while (my $st = $iter->next) {
+		my @nodes	= $st->nodes;
+		$string		.= $self->_statement_as_string( $st );
+		if ($nodes[2]->is_blank) {
+			$string	.= $self->_serialize_bounded_description( $model, $nodes[2], $seen );
+		}
 	}
 	return $string;
 }
